
package edu.uwec.cs.wickmr.life.command;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.JPanel;

public class GameOfLifePanel extends JPanel implements GameConstants {

	protected GameOfLife game;
	protected int cellHeight;
	protected int cellWidth;
	protected Color liveColor;
	protected Color deadColor;
	
	// Build the view of the given game using the given width, height, and color scheme.
	public GameOfLifePanel(GameOfLife game, Color liveColor, Color deadColor){
		this.game = game;
		this.cellWidth = GRID_WIDTH / game.getCols();
		this.cellHeight = GRID_HEIGHT / game.getRows();
		this.liveColor = liveColor;
		this.deadColor = deadColor;
		initialize();
	}
	// Initialize the UI and build the mouse listener for placing/removing lives
	// from the game.
	protected void initialize(){
		this.setSize(GRID_WIDTH, GRID_HEIGHT);
		this.setPreferredSize(this.getSize());
		this.setBackground(deadColor);
		this.setBorder(BorderFactory.createLineBorder(Color.black));
		this.addMouseListener(new MouseListener(){
			public void mouseClicked(MouseEvent e) {}
			public void mouseEntered(MouseEvent e) {}
			public void mouseExited(MouseEvent e) {}
			public void mouseReleased(MouseEvent e) {}
			public void mousePressed(MouseEvent e) {
				game.toggle(e.getPoint().y / cellHeight, e.getPoint().x / cellWidth);
			}

		});
	}
	
	//	Necessary painting method which draws the lines of the grid and the live cells.
	public void paintComponent(Graphics g){
		super.paintComponent(g);
		drawGrid(g);
		drawLives(g);
	}
	
	// Draws the lines of the grid.
	protected void drawGrid(Graphics g){
		g.setColor(liveColor);
		for(int i = 0; i <= game.getRows(); i++){
			g.drawLine(0,i*cellHeight,GRID_WIDTH,i*cellHeight);
		}
		for(int i = 0; i <= game.getCols(); i++){
			g.drawLine(i*cellWidth,0,i*cellWidth,GRID_HEIGHT);
		}
	}
	
	// Draws all live cells.
	protected void drawLives(Graphics g){
		g.setColor(liveColor);
		for(int i =0; i < game.getRows(); i++){
			for(int j = 0; j < game.getCols(); j++){
				if ( game.isAlive(i,j) ){
					g.fillRect(j*cellWidth,i*cellHeight,cellWidth,cellHeight);
				}
			}
		}
	}
	
}
